measuretools.get_one_indexed_measure_number_in_expr
===================================================

.. autofunction:: abjad.tools.measuretools.get_one_indexed_measure_number_in_expr.get_one_indexed_measure_number_in_expr
